package project1;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JTextField;

import com.google.gson.Gson;
import com.google.gson.JsonObject;
import com.google.gson.JsonParser;

import okhttp3.MediaType;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;

public class Main {
    private JFrame frame;
    private static JTextField inputField;
    private static JTextField outputField;
    private JButton button;

    public Main() {
        frame = new JFrame("Ask GPT");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setSize(400, 150);
        frame.setLocationRelativeTo(null);

        inputField = new JTextField();
        inputField.setBounds(20, 20, 300, 25);
        frame.add(inputField);

        button = new JButton("Ask");
        button.setBounds(320, 20, 60, 25);
        frame.add(button);

        outputField = new JTextField();
        outputField.setBounds(20, 60, 360, 25);
        outputField.setEditable(false);
        frame.add(outputField);

        button.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                String question = inputField.getText();
                try {
                    String response = GPT.generateText(question);
                    JsonObject json = JsonParser.parseString(response).getAsJsonObject();
                    String output = json.get("choices").getAsJsonArray().get(0).getAsJsonObject().get("text").getAsString();
                    outputField.setText(output);
                } catch (IOException ex) {
                    JOptionPane.showMessageDialog(frame, "Error: " + ex.getMessage(), "Error", JOptionPane.ERROR_MESSAGE);
                }
            }
        });

        frame.setLayout(null);
        frame.setVisible(true);
    }

    public static void main(String[] args) {
        try {
            String apiKey = JOptionPane.showInputDialog(null, "Enter your api key:");
            if (apiKey != null && !apiKey.isEmpty()) {
                OkHttpClient client = new OkHttpClient().newBuilder()
                        .build();
                Gson gson = new Gson();
                JsonObject json = new JsonObject();
                json.addProperty("prompt", inputField.getText());
                String jsonString = gson.toJson(json);

                MediaType mediaType = MediaType.parse("application/json");
                RequestBody body = RequestBody.create(jsonString,mediaType);
                Request request = new Request.Builder()
                        .url("https://api.openai.com/v1/engines/ada/completions")
                        .method("POST", body)
                        .addHeader("Content-Type", "application/json")
                        .addHeader("Authorization", "Bearer " + apiKey)
                        .build();

                Response response = client.newCall(request).execute();
                if (response.code() == 401) {
                    throw new IOException("Unauthorized: Invalid API key");
                }
                if (response.code() == 429) {
                    throw new IOException("Too Many Requests: Usage limits reached");
                }
                if (response.code() != 200) {
                    throw new IOException("Unexpected response code: " + response.code());
                }
                String res = response.body().string();
                JsonObject jsonRes = JsonParser.parseString(res).getAsJsonObject();
                String output = jsonRes.get("choices").getAsJsonArray().get(0).getAsJsonObject().get("text").getAsString();
                outputField.setText(output);
                JOptionPane.showMessageDialog(null, "Connected to GPT API!", "API Connection", JOptionPane.INFORMATION_MESSAGE);
                new Main();
            }else{
                throw new IOException("API key not provided");
            }
        } catch (IOException e) {
            e.printStackTrace();
            JOptionPane.showMessageDialog(null, "Error: " + e.getMessage(), "Error", JOptionPane.ERROR_MESSAGE);
        }
    }
}
    

